@@ -1,6 +1,7 @@
 import re
+from pathlib import Path
 
-CLOUD_PROTOCOL = "cloud://"
+CLOUD_PROTOCOL = "sc://"
 
 
 def is_cloud_path(path: str) -> bool:
@@ -25,3 +26,15 @@ def strip_cloud_protocol(path: str) -> str:
         cloudpath = cloudpath[1:]
 
     return cloudpath
+
+def strip_local_root(local_root: Path, path: Path) -> str:
+
+    parts = list(path.parts)
+
+    for p in local_root.parts:
+        if p == parts[0]:
+            parts.pop(0)
+        else:
+            raise RuntimeError(f"Tried to remove the root from a path that was outside the root.\n\tRoot: {local_root}\n\tPath: {path}")
+
+    return "/" + "/".join(parts)
